@@ -152,7 +152,7 @@ class ChecklistAdmin(ChecklistsModelAdmin):
     list_display = ('location', 'reporter', 'added_on', 'date',
                     'show_activity', 'source_link', 'species_count', 'include')
     ordering = ('-date',)
-    search_fields = ('location__name', 'location__county', 'reporter')
+    search_fields = ('location__name', 'location__county', 'reporter__name')
     list_filter = ('include', 'activity', 'source', 'added_on')
     inlines = [MethodInline, EntryInline]
     actions = ['filter_on_location', 'filter_on_reporter',
