@@ -4,6 +4,7 @@ import autocomplete_light
 
 from django import forms
 from django.db.models import Q
+from django.db.models.query import QuerySet
 from django.utils.translation import ugettext_lazy as _
 
 from models import Checklist, Entry, EntryTag, Map
@@ -12,9 +13,8 @@ from utils import tags_string, parse_tags, i18n_fieldnames
 
 class TagsWidget(forms.TextInput):
     def render(self, name, value, attrs=None):
-        if value is not None and not isinstance(value, basestring):
-            objs = EntryTag.objects.filter(id__in=value)
-            value = tags_string(objs)
+        if value is not None and isinstance(value, QuerySet):
+            value = tags_string(value)
         return super(TagsWidget, self).render(name, value, attrs)
 
 
@@ -36,7 +36,7 @@ class StatusField(forms.CharField):
                         reduce(operator.or_, filters)))
                 except EntryTag.DoesNotExist:
                     raise forms.ValidationError(
-                        _("EntryTag %s does not exist."))
+                        _("EntryTag does not exist: ") + value)
             return objs
         except ValueError:
             raise forms.ValidationError(
@@ -50,6 +50,18 @@ class EntryInlineAdminForm(forms.ModelForm):
         model = Entry
         widgets = autocomplete_light.get_widgets_dict(Entry)
 
+    def __init__(self, *args, **kwargs):
+        super(EntryInlineAdminForm, self).__init__(*args, **kwargs)
+        if self.instance.pk:
+            self.fields['status'].initial = self.instance.tags.all()
+
+    def save(self, commit=True):
+        instance = super(EntryInlineAdminForm, self).save(commit=commit)
+        instance.tags.clear()
+        for tag in self.cleaned_data.get('status', []):
+            instance.tags.add(tag)
+        return instance
+
 
 class ChecklistForm(forms.ModelForm):
 
