@@ -6,15 +6,13 @@ existing database.
 """
 
 from checklists import get_data_path
-from checklists.models import Activity, set_current_user, clear_current_user
+from checklists.models import Activity
 from checklists.utils import i18n_fieldnames
 
 from utils import create_objects, get_data
 
 
 def run():
-    set_current_user('load_activities')
     fields = ('id', 'slug') + i18n_fieldnames('name')
     data = get_data(get_data_path('activity.csv'))
     create_objects(Activity, fields, data)
-    clear_current_user()
