@@ -8,15 +8,13 @@ existing database.
 from django.db import transaction
 
 from checklists import get_data_path
-from checklists.models import SpeciesGroup, Species, Rank, set_current_user, \
-    clear_current_user
+from checklists.models import SpeciesGroup, Species, Rank
 
 from utils import get_data, get_languages
 
 
 @transaction.commit_on_success
 def run():
-    set_current_user('load_taxonomy')
     table = get_data(get_data_path('taxonomy.csv'))
     group_id = species_id = 1
     for index in range(1, len(table)):
@@ -44,4 +42,3 @@ def run():
         )
         if created:
             species_id += 1
-    clear_current_user()
